@@ -30,6 +30,7 @@ const char* kCreateSubrepoUrl = "api2/repos/%1/dir/sub_repo/";
 const char* kUnseenMessagesUrl = "api2/unseen_messages/";
 const char* kDefaultRepoUrl = "api2/default-repo/";
 const char* kStarredFilesUrl = "api2/starredfiles/";
+const char* kStarredItemsUrl = "api/v2.1/starred-items/";
 const char* kGetEventsUrl = "api2/events/";
 const char* kCommitDetailsUrl = "api2/repo_history_changes/";
 const char* kAvatarUrl = "api2/avatars/user/";
@@ -49,6 +50,7 @@ const char* kSearchUsersUrl = "api2/search-user/";
 const char* kGetThumbnailUrl = "api2/repos/%1/thumbnail/";
 const char* kCreateFileUploadLink = "api/v2.1/upload-links/";
 
+const char* kGetFileActivitiesUrl = "api/v2.1/activities/";
 } // namespace
 
 
@@ -174,9 +176,11 @@ RepoDownloadInfo RepoDownloadInfo::fromDict(QMap<QString, QVariant>& dict,
     url.setPath("/");
     info.relay_addr = url.host();
 
+    QString salt = dict.value("salt").toString();
     QMap<QString, QVariant> map;
     map.insert("is_readonly", read_only ? 1 : 0);
     map.insert("server_url", url.toString());
+    map.insert("repo_salt", salt);
 
     info.more_info = ::mapToJson(map);
 
@@ -268,6 +272,27 @@ CreateRepoRequest::CreateRepoRequest(const Account& account,
     setFormParam("random_key", random_key);
 }
 
+CreateRepoRequest::CreateRepoRequest(const Account& account,
+                                     const QString& name,
+                                     const QString& desc,
+                                     int enc_version,
+                                     const QString& repo_id,
+                                     const QString& magic,
+                                     const QString& random_key,
+                                     const QString& salt)
+    : SeafileApiRequest(account.getAbsoluteUrl(kCreateRepoUrl),
+                        SeafileApiRequest::METHOD_POST,
+                        account.token)
+{
+    setFormParam("name", name);
+    setFormParam("desc", desc);
+    setFormParam("enc_version", QString::number(enc_version));
+    setFormParam("repo_id", repo_id);
+    setFormParam("magic", magic);
+    setFormParam("random_key", random_key);
+    setFormParam("salt", salt);
+}
+
 void CreateRepoRequest::requestSuccess(QNetworkReply& reply)
 {
     json_error_t error;
@@ -451,11 +476,67 @@ void GetStarredFilesRequest::requestSuccess(QNetworkReply& reply)
 
     QScopedPointer<json_t, JsonPointerCustomDeleter> json(root);
 
-    std::vector<StarredFile> files =
-        StarredFile::listFromJSON(json.data(), &error);
+    std::vector<StarredItem> files =
+        StarredItem::listFromJSON(json.data(), &error);
     emit success(files);
 }
 
+GetStarredFilesRequestV2::GetStarredFilesRequestV2(const Account& account)
+        : SeafileApiRequest(account.getAbsoluteUrl(kStarredItemsUrl),
+                            SeafileApiRequest::METHOD_GET,
+                            account.token)
+{
+}
+
+void GetStarredFilesRequestV2::requestSuccess(QNetworkReply& reply)
+{
+    json_error_t error;
+    json_t* root = parseJSON(reply, &error);
+    if (!root) {
+        qWarning("GetStarredItemsRequest: failed to parse json:%s\n",
+                 error.text);
+        emit failed(ApiError::fromJsonError());
+        return;
+    }
+
+    QScopedPointer<json_t, JsonPointerCustomDeleter> json(root);
+    json_t* array = json_object_get(json.data(), "starred_item_list");
+    std::vector<StarredItem> files =
+            StarredItem::listFromJSON(array, &error, true);
+    emit success(files);
+}
+
+// Seafile get file activities api v2.1
+// page default value is 1
+// perpage defult value is 25
+// avatar size defult value is 72, old api is 36
+GetEventsRequestV2::GetEventsRequestV2(const Account& account, int page, int perpage, int avatar_size)
+    : SeafileApiRequest(account.getAbsoluteUrl(kGetFileActivitiesUrl),
+                        SeafileApiRequest::METHOD_GET,
+                        account.token)
+{
+    setUrlParam("page", QString::number(page));
+    setUrlParam("avatar_size", QString::number(avatar_size));
+}
+
+void GetEventsRequestV2::requestSuccess(QNetworkReply& reply)
+{
+    json_error_t error;
+    json_t* root = parseJSON(reply, &error);
+    if (!root) {
+        qWarning("GetEventsRequestV2: failed to parse json:%s\n", error.text);
+        emit failed(ApiError::fromJsonError());
+        return;
+    }
+
+    QScopedPointer<json_t, JsonPointerCustomDeleter> json(root);
+
+    json_t* array = json_object_get(json.data(), "events");
+    std::vector<SeafEvent> events = SeafEvent::listFromJSON(array, &error, true);
+
+    emit success(events);
+}
+
 GetEventsRequest::GetEventsRequest(const Account& account, int start)
     : SeafileApiRequest(account.getAbsoluteUrl(kGetEventsUrl),
                         SeafileApiRequest::METHOD_GET,
@@ -656,6 +737,10 @@ void ServerInfoRequest::requestSuccess(QNetworkReply& reply)
         ret.parseVersionFromString(dict["version"].toString());
     }
 
+    if (dict.contains("encrypted_library_version")) {
+        ret.parseEncryptedLibraryVersionFromString(dict["encrypted_library_version"].toString());
+    }
+
     if (dict.contains("features")) {
         ret.parseFeatureFromStrings(dict["features"].toStringList());
     }
