@@ -17,7 +17,7 @@ class QStringList;
 
 class ServerRepo;
 class Account;
-class StarredFile;
+class StarredItem;
 class SeafEvent;
 class CommitDetails;
 
@@ -158,6 +158,15 @@ public:
                       const QString& repo_id,
                       const QString& magic,
                       const QString& random_key);
+    // Constructor for seafile encryption v3
+    CreateRepoRequest(const Account& account,
+                      const QString& name,
+                      const QString& desc,
+                      int enc_version,
+                      const QString& repo_id,
+                      const QString& magic,
+                      const QString& random_key,
+                      const QString& salt);
 
 protected slots:
     void requestSuccess(QNetworkReply& reply);
@@ -246,7 +255,7 @@ public:
     GetStarredFilesRequest(const Account& account);
 
 signals:
-    void success(const std::vector<StarredFile>& starred_files);
+    void success(const std::vector<StarredItem>& starred_files);
 
 protected slots:
     void requestSuccess(QNetworkReply& reply);
@@ -255,6 +264,23 @@ private:
     Q_DISABLE_COPY(GetStarredFilesRequest);
 };
 
+// get starred item api v2.1
+class GetStarredFilesRequestV2 : public SeafileApiRequest
+{
+Q_OBJECT
+public:
+    GetStarredFilesRequestV2(const Account& account);
+
+signals:
+    void success(const std::vector<StarredItem>& starred_files);
+
+protected slots:
+    void requestSuccess(QNetworkReply& reply);
+
+private:
+    Q_DISABLE_COPY(GetStarredFilesRequestV2);
+};
+
 class GetEventsRequest : public SeafileApiRequest
 {
     Q_OBJECT
@@ -271,6 +297,22 @@ private:
     Q_DISABLE_COPY(GetEventsRequest);
 };
 
+class GetEventsRequestV2 : public SeafileApiRequest
+{
+    Q_OBJECT
+public:
+    GetEventsRequestV2(const Account& account, int page = 1, int perpage = 25, int avatar_size = 36);
+
+signals:
+    void success(const std::vector<SeafEvent>& events);
+
+protected slots:
+    void requestSuccess(QNetworkReply& reply);
+
+private:
+    Q_DISABLE_COPY(GetEventsRequestV2);
+};
+
 class GetCommitDetailsRequest : public SeafileApiRequest
 {
     Q_OBJECT
